@@ -101,6 +101,8 @@ def castorize_column(
     study: "CastorStudy",
     variable_translation: typing.Optional[typing.Dict],
     format_options: dict,
+    target,
+    target_name,
 ) -> dict:
     """Translates the values in a column to Castorized values ready for import."""
     if new_name[0] == "record_id":
@@ -115,17 +117,98 @@ def castorize_column(
         return_value = {new_name[0]: record_column}
     else:
         return_value = castorize_column_helper(
-            label_data, new_name, study, to_import, variable_translation, format_options
+            label_data,
+            new_name,
+            study,
+            to_import,
+            variable_translation,
+            format_options,
+            target,
+            target_name,
         )
     return return_value
 
 
 def castorize_column_helper(
-    label_data, new_name, study, to_import, variable_translation, format_options
+    label_data,
+    new_name,
+    study,
+    to_import,
+    variable_translation,
+    format_options,
+    target,
+    target_name,
 ):
     """Helper function for selecting the correct way to castorize a column."""
     target_field = study.get_single_field(new_name[0])
-    if target_field.field_type in ["checkbox", "dropdown", "radio"]:
+    # Check if we want to validate field exists for parent
+    # This can be None for testing purposes
+    if target == "Study":
+        # Check for study
+        if target_field.step.form.form_type != "Study":
+            return {
+                new_name[0]: [
+                    "Error: field is not child of given target" for _ in to_import
+                ]
+            }
+    elif target == "Report":
+        # Check for reports)
+        if target_field.step.form.form_name != target_name:
+            return {
+                new_name[0]: [
+                    "Error: field is not child of given target" for _ in to_import
+                ]
+            }
+    elif target == "Survey":
+        # Check for surveys (need to extract all forms in given survey package)
+        # TODO Add survey package structure building to Study object # pylint: disable=fixme
+        # And then remove it here
+        package = next(
+            (
+                item
+                for item in study.client.all_survey_packages()
+                if item["name"] == target_name
+            ),
+            None,
+        )
+        if package is None:
+            return {
+                new_name[0]: ["Error: survey package does not exist" for _ in to_import]
+            }
+        if target_field.step.form.form_name not in [
+            survey["name"] for survey in package["_embedded"]["surveys"]
+        ]:
+            return {
+                new_name[0]: [
+                    "Error: field is not child of given target" for _ in to_import
+                ]
+            }
+
+    return_value = choose_column_castorizer(
+        format_options,
+        label_data,
+        new_name,
+        study,
+        target_field,
+        to_import,
+        variable_translation,
+    )
+    return return_value
+
+
+def choose_column_castorizer(
+    format_options,
+    label_data,
+    new_name,
+    study,
+    target_field,
+    to_import,
+    variable_translation,
+):
+    """Chooses the correct function to castorize the column."""
+    if target_field is None:
+        return_value = {new_name[0]: ["Error: field does not exist" for _ in to_import]}
+    elif target_field.field_type in ["checkbox", "dropdown", "radio"]:
         return_value = castorize_optiongroup_column_helper(
             label_data, new_name, study, target_field, to_import, variable_translation
         )
@@ -385,7 +468,11 @@ def castorize_num_column(data: list, target_field: "CastorField"):
                 # Test if data point is convertible to float
                 numeric_datapoint = float(datapoint)
                 # Test if between bounds
-                if target_field.field_max > numeric_datapoint > target_field.field_min:
+                if (
+                    target_field.field_max
+                    >= numeric_datapoint
+                    >= target_field.field_min
+                ):
                     new_list.append(datapoint)
                 else:
                     new_list.append("Error: number out of bounds")
@@ -402,7 +489,7 @@ def castorize_year_column(data: list, target_field: "CastorField"):
             new_list.append(None)
         else:
             try:
-                if target_field.field_max > int(datapoint) > target_field.field_min:
+                if target_field.field_max >= int(datapoint) >= target_field.field_min:
                     new_list.append(datapoint)
                 else:
                     new_list.append("Error: year out of bounds")
@@ -484,8 +571,8 @@ def castorize_numberdate_column(
                     # Test if between bounds
                     if (
                         target_field.field_max
-                        > numeric_datapoint
-                        > target_field.field_min
+                        >= numeric_datapoint
+                        >= target_field.field_min
                     ):
                         new_value.append(split[0])
                     else:
@@ -548,6 +635,8 @@ def create_upload(
     label_data: bool,
     study: "CastorStudy",
     format_options: dict,
+    target: typing.Optional[str],
+    target_name: typing.Optional[str],
 ) -> pd.DataFrame:
     """Returns a upload-ready dataframe from a path to an Excel file."""
     to_upload = read_excel(path_to_upload)
@@ -570,6 +659,8 @@ def create_upload(
             study=study,
             variable_translation=variable_translation,
             format_options=format_options,
+            target=target,
+            target_name=target_name,
         )
         new_data = {**new_data, **new_column}
     return pd.DataFrame.from_dict(new_data)
@@ -645,13 +736,17 @@ def create_feedback(imported):
     "Creates feedback from the (un)successful imports"
     feedback_total = {}
     for row in imported:
+        success = row.get("success", {})
+        failed = row.get("failed", {})
+        error = row.get("error", {})
+
         if row["record_id"] not in feedback_total:
             feedback_total[row["record_id"]] = [
-                {"success": row["success"], "failed": row["failed"]}
+                {"success": success, "failed": failed, "error": error}
             ]
         else:
             feedback_total[row["record_id"]].append(
-                {"success": row["success"], "failed": row["failed"]}
+                {"success": success, "failed": failed, "error": error}
             )
     return feedback_total
 
