@@ -31,7 +31,7 @@ class TestMetadata:
         },
     }
 
-    @pytest.fixture(scope="class")
+    @pytest.fixture(scope="function")
     def all_metadata(self, client):
         """Get all metadata"""
         all_metadata = client.all_metadata()
@@ -71,4 +71,4 @@ class TestMetadata:
         """Tests if single metadata returns an error."""
         with pytest.raises(HTTPStatusError) as e:
             client.single_metadata("FAKE5E29-02BB-4C90-AA02-5F27A300D99E")
-        assert "404 Client Error: Not Found for url" in str(e.value)
+        assert e.value.response.status_code == 404
