@@ -27,7 +27,7 @@ class TestMetadataType:
         },
     }
 
-    @pytest.fixture(scope="class")
+    @pytest.fixture(scope="function")
     def all_metadata_types(self, client):
         """Gets all metadata types from the API."""
         all_metadata_types = client.all_metadata_types()
@@ -67,4 +67,4 @@ class TestMetadataType:
         """Tests if single metadata_type returns an error."""
         with pytest.raises(HTTPStatusError) as e:
             client.single_metadata_type("2")
-        assert "404 Client Error: Not Found for url" in str(e.value)
+        assert e.value.response.status_code == 404
