@@ -30,7 +30,7 @@ class TestPhase:
         },
     }
 
-    @pytest.fixture(scope="class")
+    @pytest.fixture(scope="function")
     def all_phases(self, client):
         """Get all phases in the study."""
         all_phases = client.all_phases()
@@ -68,4 +68,4 @@ class TestPhase:
         """Tests if single phase returns an error."""
         with pytest.raises(HTTPStatusError) as e:
             client.single_phase("FAKE95D-4F8D-4B4A-96A1-14D026D0328E")
-        assert "404 Client Error: Not Found for url" in str(e.value)
+        assert e.value.response.status_code == 404
