@@ -29,7 +29,7 @@ class TestReport:
         },
     }
 
-    @pytest.fixture(scope="class")
+    @pytest.fixture(scope="function")
     def all_reports(self, client):
         """Gets all reports from the study."""
         all_reports = client.all_reports()
@@ -74,4 +74,4 @@ class TestReport:
         """Tests if single report returns an error."""
         with pytest.raises(HTTPStatusError) as e:
             client.single_report("FAKEB401-6100-4CF5-A95F-3402B55EAC48")
-        assert "404 Client Error: Not Found for url" in str(e.value)
+        assert e.value.response.status_code == 404
