@@ -6,21 +6,21 @@ from castoredc_api.importer.helpers import read_excel, castorize_column
 class TestLabelTranslation:
     """Tests the helper functions for translation of external variable labels to Castor labels."""
 
-    @pytest.fixture(scope="class")
+    @pytest.fixture(scope="function")
     def study_label_data(self):
         dataframe = read_excel(
             "tests/test_import/data_files_for_import_tests/data_file_study_labels.xlsx"
         )
         return dataframe
 
-    @pytest.fixture(scope="class")
+    @pytest.fixture(scope="function")
     def medication_label_data(self):
         dataframe = read_excel(
             "tests/test_import/data_files_for_import_tests/data_file_report_medication_labels.xlsx"
         )
         return dataframe
 
-    @pytest.fixture(scope="class")
+    @pytest.fixture(scope="function")
     def survey_label_data(self):
         dataframe = read_excel(
             "tests/test_import/data_files_for_import_tests/data_file_survey_labels.xlsx"
@@ -41,6 +41,8 @@ class TestLabelTranslation:
                 "datetime": "%d-%m-%Y;%H:%M",
                 "time": "%H:%M",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {
             "record_id": ["110001", "110002", "110003", "110004", "110005"]
@@ -60,6 +62,8 @@ class TestLabelTranslation:
                 "datetime": "%d-%m-%Y;%H:%M",
                 "time": "%H:%M",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {"his_family": ["2;3;4", "1;2", "0", "5;7", "8"]}
 
@@ -77,6 +81,8 @@ class TestLabelTranslation:
                 "datetime": "%d-%m-%Y;%H:%M",
                 "time": "%H:%M",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {
             "base_bl_date": [
@@ -102,6 +108,8 @@ class TestLabelTranslation:
                 "datetime": "%d-%m-%Y;%H:%M",
                 "time": "%H:%M",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {
             "onset_stroke": [
@@ -127,6 +135,8 @@ class TestLabelTranslation:
                 "datetime": "%d-%m-%Y;%H:%M",
                 "time": "%H:%M",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {"pat_race": ["1", "2", "3", "4", "5"]}
 
@@ -144,6 +154,8 @@ class TestLabelTranslation:
                 "datetime": "%d-%m-%Y;%H:%M",
                 "time": "%H:%M",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {
             "fac_V_leiden": [
@@ -169,6 +181,8 @@ class TestLabelTranslation:
                 "datetime": "%d-%m-%Y;%H:%M",
                 "time": "%H:%M",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {"base_hb": ["8.3", "7.2", "9.1", "3.2", "10.3"]}
 
@@ -186,6 +200,8 @@ class TestLabelTranslation:
                 "datetime": "%d-%m-%Y;%H:%M",
                 "time": "%H:%M",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {"pat_sex": ["0", "0", "1", "1", "0"]}
 
@@ -205,6 +221,8 @@ class TestLabelTranslation:
                 "datetime": "%d-%m-%Y;%H:%M",
                 "time": "%H:%M",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {
             "med_units": ["3", "7", "7", "2", "2"],
@@ -225,6 +243,8 @@ class TestLabelTranslation:
                 "datetime": "%d-%m-%Y;%H:%M",
                 "time": "%H:%M",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {"VAS": ["25", "88", "13"]}
 
@@ -242,6 +262,8 @@ class TestLabelTranslation:
                 "datetime": "%d-%m-%Y;%H:%M",
                 "time": "%H:%M",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {
             "med_name": [
@@ -267,6 +289,8 @@ class TestLabelTranslation:
                 "datetime": "%d-%m-%Y;%H:%M",
                 "time": "%H:%M",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {
             "onset_trombectomy": ["09:25", "06:33", "12:24", "23:23", "08:14"]
@@ -286,6 +310,8 @@ class TestLabelTranslation:
                 "datetime": "%d-%m-%Y;%H:%M",
                 "time": "%H:%M",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {
             "pat_birth_year": ["1999", "1956", "1945", "1933", "1921"]
@@ -295,21 +321,21 @@ class TestLabelTranslation:
 class TestLabelTranslationMissing:
     """Tests the helper functions for translation of external variable labels to Castor labels with missing labels."""
 
-    @pytest.fixture(scope="class")
+    @pytest.fixture(scope="function")
     def study_label_data(self):
         dataframe = read_excel(
             "tests/test_import/data_files_for_import_tests/data_file_study_labels_missings.xlsx"
         )
         return dataframe
 
-    @pytest.fixture(scope="class")
+    @pytest.fixture(scope="function")
     def medication_label_data(self):
         dataframe = read_excel(
             "tests/test_import/data_files_for_import_tests/data_file_report_medication_labels_missings.xlsx"
         )
         return dataframe
 
-    @pytest.fixture(scope="class")
+    @pytest.fixture(scope="function")
     def survey_label_data(self):
         dataframe = read_excel(
             "tests/test_import/data_files_for_import_tests/data_file_survey_labels_missings.xlsx"
@@ -330,6 +356,8 @@ class TestLabelTranslationMissing:
                 "datetime": "%d-%m-%Y;%H:%M",
                 "time": "%H:%M",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {
             "record_id": ["110001", "110002", "110003", "110004", "110005"]
@@ -349,6 +377,8 @@ class TestLabelTranslationMissing:
                 "datetime": "%d-%m-%Y;%H:%M",
                 "time": "%H:%M",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {"his_family": [None, None, "0", "5;7", "8"]}
 
@@ -366,6 +396,8 @@ class TestLabelTranslationMissing:
                 "datetime": "%d-%m-%Y;%H:%M",
                 "time": "%H:%M",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {
             "base_bl_date": [
@@ -391,6 +423,8 @@ class TestLabelTranslationMissing:
                 "datetime": "%d-%m-%Y;%H:%M",
                 "time": "%H:%M",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {
             "onset_stroke": [
@@ -416,6 +450,8 @@ class TestLabelTranslationMissing:
                 "datetime": "%d-%m-%Y;%H:%M",
                 "time": "%H:%M",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {"pat_race": ["1", "2", None, "4", "5"]}
 
@@ -433,6 +469,8 @@ class TestLabelTranslationMissing:
                 "datetime": "%d-%m-%Y;%H:%M",
                 "time": "%H:%M",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {
             "fac_V_leiden": [
@@ -458,6 +496,8 @@ class TestLabelTranslationMissing:
                 "datetime": "%d-%m-%Y;%H:%M",
                 "time": "%H:%M",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {"base_hb": ["8.3", None, "9.1", "3.2", "10.3"]}
 
@@ -475,6 +515,8 @@ class TestLabelTranslationMissing:
                 "datetime": "%d-%m-%Y;%H:%M",
                 "time": "%H:%M",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {"pat_sex": ["0", "0", None, "1", "0"]}
 
@@ -494,6 +536,8 @@ class TestLabelTranslationMissing:
                 "datetime": "%d-%m-%Y;%H:%M",
                 "time": "%H:%M",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {
             "med_units": ["3", None, "7", "2", None],
@@ -514,6 +558,8 @@ class TestLabelTranslationMissing:
                 "datetime": "%d-%m-%Y;%H:%M",
                 "time": "%H:%M",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {"VAS": ["25", None, "13"]}
 
@@ -531,6 +577,8 @@ class TestLabelTranslationMissing:
                 "datetime": "%d-%m-%Y;%H:%M",
                 "time": "%H:%M",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {
             "med_name": ["Azathioprine", None, None, "Thioguanine", "Tofacitinib"]
@@ -550,6 +598,8 @@ class TestLabelTranslationMissing:
                 "datetime": "%d-%m-%Y;%H:%M",
                 "time": "%H:%M",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {
             "onset_trombectomy": ["09:25", "06:33", "12:24", None, "08:14"]
@@ -569,6 +619,8 @@ class TestLabelTranslationMissing:
                 "datetime": "%d-%m-%Y;%H:%M",
                 "time": "%H:%M",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {"pat_birth_year": ["1999", None, None, None, "1921"]}
 
@@ -576,21 +628,21 @@ class TestLabelTranslationMissing:
 class TestLabelTranslationFail:
     """Tests the helper functions for translation of erronous external variable labels to Castor labels."""
 
-    @pytest.fixture(scope="class")
+    @pytest.fixture(scope="function")
     def study_label_data_error(self):
         dataframe = read_excel(
             "tests/test_import/data_files_for_import_tests/data_file_study_labels_errors.xlsx"
         )
         return dataframe
 
-    @pytest.fixture(scope="class")
+    @pytest.fixture(scope="function")
     def medication_label_data_error(self):
         dataframe = read_excel(
             "tests/test_import/data_files_for_import_tests/data_file_report_medication_labels_errors.xlsx"
         )
         return dataframe
 
-    @pytest.fixture(scope="class")
+    @pytest.fixture(scope="function")
     def survey_label_data_error(self):
         dataframe = read_excel(
             "tests/test_import/data_files_for_import_tests/data_file_survey_labels_errors.xlsx"
@@ -611,6 +663,8 @@ class TestLabelTranslationFail:
                 "datetime": "%d-%m-%Y;%H:%M",
                 "time": "%H:%M",
             },
+            target=None,
+            target_name=None,
         )
         # Record checking fails at the import stage
         assert import_column == {
@@ -637,6 +691,8 @@ class TestLabelTranslationFail:
                 "datetime": "%d-%m-%Y;%H:%M",
                 "time": "%H:%M",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {
             "his_family": [
@@ -662,6 +718,8 @@ class TestLabelTranslationFail:
                 "datetime": "%d-%m-%Y;%H:%M",
                 "time": "%H:%M",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {
             "base_bl_date": [
@@ -687,6 +745,8 @@ class TestLabelTranslationFail:
                 "datetime": "%d-%m-%Y;%H:%M",
                 "time": "%H:%M",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {
             "onset_stroke": [
@@ -712,6 +772,8 @@ class TestLabelTranslationFail:
                 "datetime": "%d-%m-%Y;%H:%M",
                 "time": "%H:%M",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {
             "pat_race": [
@@ -737,6 +799,8 @@ class TestLabelTranslationFail:
                 "datetime": "%d-%m-%Y;%H:%M",
                 "time": "%H:%M",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {
             "fac_V_leiden": [
@@ -762,6 +826,8 @@ class TestLabelTranslationFail:
                 "datetime": "%d-%m-%Y;%H:%M",
                 "time": "%H:%M",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {
             "base_hb": [
@@ -787,6 +853,8 @@ class TestLabelTranslationFail:
                 "datetime": "%d-%m-%Y;%H:%M",
                 "time": "%H:%M",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {
             "pat_sex": [
@@ -814,6 +882,8 @@ class TestLabelTranslationFail:
                 "datetime": "%d-%m-%Y;%H:%M",
                 "time": "%H:%M",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {
             "med_units": ["7", "7", "7", "7", "7"],
@@ -834,6 +904,8 @@ class TestLabelTranslationFail:
                 "datetime": "%d-%m-%Y;%H:%M",
                 "time": "%H:%M",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {
             "VAS": ["Error: not a number", "Error: not a number", "Error: not a number"]
@@ -853,6 +925,8 @@ class TestLabelTranslationFail:
                 "datetime": "%d-%m-%Y;%H:%M",
                 "time": "%H:%M",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {"med_name": ["cant", "be", "wrong", "cuz", "text"]}
 
@@ -870,6 +944,8 @@ class TestLabelTranslationFail:
                 "datetime": "%d-%m-%Y;%H:%M",
                 "time": "%H:%M",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {
             "onset_trombectomy": [
@@ -895,6 +971,8 @@ class TestLabelTranslationFail:
                 "datetime": "%d-%m-%Y;%H:%M",
                 "time": "%H:%M",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {
             "pat_birth_year": [
